@@ -3,7 +3,11 @@ import sys
 
 sys.path.insert(0, os.path.abspath('../..'))
 
-extensions = ['sphinx.ext.autodoc', 'oslosphinx']
+extensions = [
+    'sphinx.ext.autodoc',
+    'oslosphinx',
+    'reno.sphinxext'
+]
 
 # The suffix of source filenames.
 source_suffix = '.rst'
